@@ -154,6 +154,8 @@ class ArgParse:
 
         # Prepare search path for configuration file. Disable it if we're looking
         # for a impossible (None) file name
+        if not cfgfilename:
+            cfgfilename = "flask.yml"
         if cfgfilepaths is None:
             cfgfilepaths = CFGFILE_SEARCH_PATHS
         cfgfilepaths = [e.format(cfgfilename=cfgfilename) for e in cfgfilepaths]
